@@ -128,6 +128,29 @@ maxratioPortfolio <-
     setTargetReturn(spec) <- getTargetReturn(fp)
     portfolio = optimize(f = ratioFun, interval = range(getMu(Data)),
         maximum = TRUE, data = Data, spec = spec, constraints = constraints)
+        
+    ## 2009-04-19 DW:
+    ## It may happen, that the maximum ratio portfolio cannot be computed.
+    ## One reason is that the portfolio does not exist since the constraints 
+    ## are too restrictive. 
+    ## Another reason is that the risk free rate is above the highest return
+    ## point.
+    ## In these cases we stop the computation here, and return an error message.
+    
+    STATUS = attr(portfolio$objective, "status")
+    if (STATUS != 0) {
+        # Error Message:
+        cat("\nExecution stopped:")   
+        cat("\n  The maximum ratio portfolio could not be computed.")
+        cat("\nPossible Reason:")
+        cat("\n  Your portfolio constraints may be too restrictive.")
+        cat("\nStatus Information:")
+        cat("\n  status=", STATUS, " from solver ", getSolver(spec), ".", sep = "")
+        cat("\n")
+        stop(call. = FALSE, show.error.messages = "\n  returned from Rmetrics")
+    }
+       
+    # Continue: Succesfully computed the minimum risk portfolio ...     
     setWeights(spec) <- attr(portfolio$objective, "weights")
     setStatus(spec) <- attr(portfolio$objective, "status")
 
@@ -147,6 +170,18 @@ maxratioPortfolio <-
 tangencyPortfolio <-
     function(data, spec = portfolioSpec(), constraints = "LongOnly")
 {
+    # A function implemented by Diethelm Wuertz
+    
+    # Description:
+    #   Computes Markowitz tangency portfolio
+    
+    # Arguments:
+    #   data - a rectangular object of assets
+    #   spec - an object of class 'fPFOLIOSPEC'
+    #   constraints - a character vector or NULL
+    
+    # FUNCTION:
+    
     # Portfolio:
     portfolio = maxratioPortfolio(data, spec, constraints)
     portfolio@title = "Tangency Portfolio"
@@ -165,7 +200,7 @@ minriskPortfolio <-
     # A function implemented by Diethelm Wuertz
 
     # Description:
-    #   Computes minimum variance portfolio
+    #   Computes minimum risk portfolio
 
     # Arguments:
     #   data - a rectangular object of assets
@@ -173,13 +208,12 @@ minriskPortfolio <-
     #   constraints - a character vector or NULL
 
     # Example:
-    #   data = as.timeSeries(data(smallcap.ts))[,c("BKE","GG","GYMB","KRON")]
-    #   minriskPortfolio(data)
+    #   minriskPortfolio(SWX[, 1:3])
 
     # FUNCTION:
 
     # Match Spec Versus Constraints:
-    # .checkSpecVsConstraints(spec, constraints)
+    #   .checkSpecVsConstraints(spec, constraints)
 
     # Transform Data:
     Data = portfolioData(data, spec)
@@ -200,6 +234,27 @@ minriskPortfolio <-
     # Minimal Risk:
     portfolio <- optimize(targetRiskFun, interval = range(getMu(Data)),
         data = Data, spec = spec, constraints = constraints)
+        
+    ## 2009-04-19 DW:
+    ## It may happen, that the minimum risk protfolio cannot be computed.
+    ## One reason is that the portfolio does not exist since the constraints 
+    ## are too restrictive. 
+    ## In this case we stop the computation here, and return an error message.
+    
+    STATUS = attr(portfolio$objective, "status")
+    if (STATUS != 0) {
+        # Error Message:
+        cat("\nExecution stopped:")   
+        cat("\n  The minimum risk portfolio could not be computed.")
+        cat("\nPossible Reason:")
+        cat("\n  Your portfolio constraints may be too restrictive.")
+        cat("\nStatus Information:")
+        cat("\n  status=", STATUS, " from solver ", getSolver(spec), ".", sep = "")
+        cat("\n")
+        stop(call.= FALSE, show.error.messages = "\n  returned from Rmetrics")
+    }
+       
+    # Continue: Succesfully computed the minimum risk portfolio ...  
     setWeights(spec) <- attr(portfolio$objective, "weights")
     setStatus(spec) <- attr(portfolio$objective, "status")
 
@@ -219,6 +274,18 @@ minriskPortfolio <-
 minvariancePortfolio <-
     function(data, spec = portfolioSpec(), constraints = "LongOnly")
 {
+    # A function implemented by Diethelm Wuertz
+    
+    # Description:
+    #   Computes global minimum variance portfolio
+    
+    # Arguments:
+    #   data - a rectangular object of assets
+    #   spec - an object of class 'fPFOLIOSPEC'
+    #   constraints - a character vector or NULL
+    
+    # FUNCTION:
+    
     # Portfolio:
     portfolio = minriskPortfolio(data, spec, constraints)
     portfolio@title = "Minimum Variance Portfolio"
